@@ -1,7 +1,7 @@
 /*
  * AssistantAction.java
  * 
- * Copyright (c) 2009-2011 Guillaume Mazoyer
+ * Copyright (c) 2009-2013 Guillaume Mazoyer
  * 
  * This file is part of GNOME Split.
  * 
@@ -20,12 +20,11 @@
  */
 package org.gnome.split.gtk.action;
 
-import org.gnome.gtk.Stock;
-import org.gnome.split.GnomeSplit;
-import org.gnome.split.gtk.widget.assistant.ActionAssistant;
-
 import static org.freedesktop.bindings.Internationalization._;
 
+import org.gnome.gtk.Stock;
+import org.gnome.split.gtk.dialog.AssistantDialog;
+
 /**
  * Allow the user to use the assistant.
  * 
@@ -33,12 +32,12 @@ import static org.freedesktop.bindings.Internationalization._;
  */
 final class AssistantAction extends Action
 {
-    protected AssistantAction(final GnomeSplit app) {
-        super(app, "assistant-action", _("_Assistant"), _("Create a split or a merge."), Stock.ADD);
+    protected AssistantAction() {
+        super("assistant-action", _("_Assistant"), _("Create a split or a merge."), Stock.ADD);
     }
 
     @Override
     public void onActivate(org.gnome.gtk.Action source) {
-        new ActionAssistant(this.getApplication()).showAll();
+        new AssistantDialog().present();
     }
 }
