@@ -1,7 +1,7 @@
 /*
  * PreferencesAction.java
  * 
- * Copyright (c) 2009-2011 Guillaume Mazoyer
+ * Copyright (c) 2009-2013 Guillaume Mazoyer
  * 
  * This file is part of GNOME Split.
  * 
@@ -21,7 +21,6 @@
 package org.gnome.split.gtk.action;
 
 import org.gnome.gtk.Stock;
-import org.gnome.split.GnomeSplit;
 import org.gnome.split.gtk.dialog.PreferencesDialog;
 
 /**
@@ -31,12 +30,12 @@ import org.gnome.split.gtk.dialog.PreferencesDialog;
  */
 final class PreferencesAction extends Action
 {
-    protected PreferencesAction(final GnomeSplit app) {
-        super(app, "preferences-action", Stock.PREFERENCES);
+    protected PreferencesAction() {
+        super("preferences-action", Stock.PREFERENCES);
     }
 
     @Override
     public void onActivate(org.gnome.gtk.Action source) {
-        new PreferencesDialog(this.getApplication()).present();
+        new PreferencesDialog().present();
     }
 }
