@@ -1,7 +1,7 @@
 /*
  * PreferencesDialog.java
  * 
- * Copyright (c) 2009-2011 Guillaume Mazoyer
+ * Copyright (c) 2009-2013 Guillaume Mazoyer
  * 
  * This file is part of GNOME Split.
  * 
@@ -20,6 +20,10 @@
  */
 package org.gnome.split.gtk.dialog;
 
+import static org.freedesktop.bindings.Internationalization._;
+import static org.gnome.split.GnomeSplit.config;
+import static org.gnome.split.GnomeSplit.ui;
+
 import org.gnome.gdk.Event;
 import org.gnome.gtk.Button;
 import org.gnome.gtk.CheckButton;
@@ -44,13 +48,9 @@ import org.gnome.gtk.VBox;
 import org.gnome.gtk.Widget;
 import org.gnome.gtk.Window;
 import org.gnome.notify.Notify;
-import org.gnome.split.GnomeSplit;
-import org.gnome.split.config.Configuration;
 import org.gnome.split.config.Constants;
 import org.gnome.split.core.utils.Algorithm;
 
-import static org.freedesktop.bindings.Internationalization._;
-
 /**
  * This class is used to build GTK+ Preferences dialog.
  * 
@@ -58,16 +58,6 @@ import static org.freedesktop.bindings.Internationalization._;
  */
 public final class PreferencesDialog extends Dialog implements Window.DeleteEvent, Dialog.Response
 {
-    /**
-     * Configuration of the application.
-     */
-    private final Configuration config;
-
-    /**
-     * Current instance of the application.
-     */
-    private GnomeSplit app;
-
     /**
      * Directory chooser for the split widget.
      */
@@ -78,12 +68,8 @@ public final class PreferencesDialog extends Dialog implements Window.DeleteEven
      */
     private FileChooserButton mergeDirChooser;
 
-    public PreferencesDialog(final GnomeSplit app) {
-        super(_("GNOME Split Preferences"), app.getMainWindow(), false);
-
-        // Get configuration
-        this.config = app.getConfig();
-        this.app = app;
+    public PreferencesDialog() {
+        super(_("GNOME Split Preferences"), ui, false);
 
         // Border width
         this.setBorderWidth(12);
@@ -111,14 +97,14 @@ public final class PreferencesDialog extends Dialog implements Window.DeleteEven
     /**
      * Just create a label with 4 spaces in it for alignment reason.
      */
-    private Label createEmptyLabel() {
+    private static Label createEmptyLabel() {
         return new Label("    ");
     }
 
     /**
      * Create a label justified to the left and using bold font.
      */
-    private Label createSectionLabel(String text) {
+    private static Label createSectionLabel(String text) {
         // Create the label
         final Label label = new Label("<b>" + text + "</b>");
 
@@ -145,14 +131,14 @@ public final class PreferencesDialog extends Dialog implements Window.DeleteEven
         page.packStart(first, false, false, 0);
 
         // Add the label
-        first.packStart(this.createSectionLabel(_("Assistant")), false, false, 0);
+        first.packStart(createSectionLabel(_("Assistant")), false, false, 0);
 
         // Add the row of options
         final HBox firstRow = new HBox(false, 0);
         first.packStart(firstRow, false, false, 0);
 
         // Add an empty label
-        firstRow.packStart(this.createEmptyLabel(), false, false, 0);
+        firstRow.packStart(createEmptyLabel(), false, false, 0);
 
         // Add the option
         final CheckButton assistant = new CheckButton(_("_Show the assistant on start"));
@@ -172,14 +158,14 @@ public final class PreferencesDialog extends Dialog implements Window.DeleteEven
         page.packStart(second, false, false, 0);
 
         // Add the label
-        second.packStart(this.createSectionLabel(_("Program run")), false, false, 0);
+        second.packStart(createSectionLabel(_("Program run")), false, false, 0);
 
         // Add the row of options
         final HBox secondRow = new HBox(false, 0);
         second.packStart(secondRow, false, false, 0);
 
         // Add an empty label
-        secondRow.packStart(this.createEmptyLabel(), false, false, 0);
+        secondRow.packStart(createEmptyLabel(), false, false, 0);
 
         // Restore multiple instances status
         final CheckButton instances = new CheckButton(_("_Allow multiple instances."));
@@ -215,14 +201,14 @@ public final class PreferencesDialog extends Dialog implements Window.DeleteEven
         page.packStart(first, false, false, 0);
 
         // Add the label
-        first.packStart(this.createSectionLabel(_("Default view")), false, false, 0);
+        first.packStart(createSectionLabel(_("Default view")), false, false, 0);
 
         // Add the row of options
         final HBox firstRow = new HBox(false, 0);
         first.packStart(firstRow, false, false, 0);
 
         // Add an empty label
-        firstRow.packStart(this.createEmptyLabel(), false, false, 0);
+        firstRow.packStart(createEmptyLabel(), false, false, 0);
 
         // Pack the options
         final VBox boxes = new VBox(false, 6);
@@ -263,14 +249,14 @@ public final class PreferencesDialog extends Dialog implements Window.DeleteEven
         page.packStart(second, false, false, 0);
 
         // Add the label
-        second.packStart(this.createSectionLabel(_("Size of the main window")), false, false, 0);
+        second.packStart(createSectionLabel(_("Size of the main window")), false, false, 0);
 
         // Add the row of options
         final HBox secondRow = new HBox(false, 0);
         second.packStart(secondRow, false, false, 0);
 
         // Add an empty label
-        secondRow.packStart(this.createEmptyLabel(), false, false, 0);
+        secondRow.packStart(createEmptyLabel(), false, false, 0);
 
         // Add a box to pack widgets to change the size
         final VBox sizeBox = new VBox(false, 6);
@@ -346,8 +332,8 @@ public final class PreferencesDialog extends Dialog implements Window.DeleteEven
         useCurrent.connect(new Button.Clicked() {
             @Override
             public void onClicked(Button source) {
-                double x = (double) app.getMainWindow().getWidth();
-                double y = (double) app.getMainWindow().getHeight();
+                double x = (double) ui.getWidth();
+                double y = (double) ui.getHeight();
 
                 // Update the widgets
                 width.setValue(x);
@@ -366,7 +352,7 @@ public final class PreferencesDialog extends Dialog implements Window.DeleteEven
                 int height = config.WINDOW_SIZE_Y;
 
                 // Resize the window
-                app.getMainWindow().resize(width, height);
+                ui.resize(width, height);
             }
         });
 
@@ -398,14 +384,14 @@ public final class PreferencesDialog extends Dialog implements Window.DeleteEven
         page.packStart(first, false, false, 0);
 
         // Add the label
-        first.packStart(this.createSectionLabel(_("During a split")), false, false, 0);
+        first.packStart(createSectionLabel(_("During a split")), false, false, 0);
 
         // Add the row of option
         final HBox firstRow = new HBox(false, 0);
         first.packStart(firstRow, false, false, 0);
 
         // Add an empty label
-        firstRow.packStart(this.createEmptyLabel(), false, false, 0);
+        firstRow.packStart(createEmptyLabel(), false, false, 0);
 
         final CheckButton md5sum = new CheckButton(_("_Calculate the MD5 sum if possible."));
         md5sum.setActive(config.SAVE_FILE_HASH);
@@ -424,14 +410,14 @@ public final class PreferencesDialog extends Dialog implements Window.DeleteEven
         page.packStart(second, false, false, 0);
 
         // Add the label
-        second.packStart(this.createSectionLabel(_("Default algorithm")), false, false, 0);
+        second.packStart(createSectionLabel(_("Default algorithm")), false, false, 0);
 
         // Add the row of option
         final HBox secondRow = new HBox(false, 0);
         second.packStart(secondRow, false, false, 0);
 
         // Add an empty label
-        secondRow.packStart(this.createEmptyLabel(), false, false, 0);
+        secondRow.packStart(createEmptyLabel(), false, false, 0);
 
         // Algorithm list
         final ComboBoxText algorithms = new ComboBoxText();
@@ -457,14 +443,14 @@ public final class PreferencesDialog extends Dialog implements Window.DeleteEven
         page.packStart(third, false, false, 0);
 
         // Add the label
-        third.packStart(this.createSectionLabel(_("Default directory")), false, false, 0);
+        third.packStart(createSectionLabel(_("Default directory")), false, false, 0);
 
         // Add the row of option
         final HBox thirdRow = new HBox(false, 0);
         third.packStart(thirdRow, false, false, 0);
 
         // Add an empty label
-        thirdRow.packStart(this.createEmptyLabel(), false, false, 0);
+        thirdRow.packStart(createEmptyLabel(), false, false, 0);
 
         // Default directory button
         splitDirChooser = new FileChooserButton(_("Choose a directory."),
@@ -495,14 +481,14 @@ public final class PreferencesDialog extends Dialog implements Window.DeleteEven
         page.packStart(first, false, false, 0);
 
         // Add the label
-        first.packStart(this.createSectionLabel(_("During a merge")), false, false, 0);
+        first.packStart(createSectionLabel(_("During a merge")), false, false, 0);
 
         // Add the row of options
         final HBox firstRow = new HBox(false, 0);
         first.packStart(firstRow, false, false, 0);
 
         // Add an empty label
-        firstRow.packStart(this.createEmptyLabel(), false, false, 0);
+        firstRow.packStart(createEmptyLabel(), false, false, 0);
 
         // Box for check buttons
         final VBox button = new VBox(false, 6);
@@ -534,14 +520,14 @@ public final class PreferencesDialog extends Dialog implements Window.DeleteEven
         page.packStart(second, false, false, 0);
 
         // Add the label
-        second.packStart(this.createSectionLabel(_("After a merge")), false, false, 0);
+        second.packStart(createSectionLabel(_("After a merge")), false, false, 0);
 
         // Add the row of options
         final HBox secondRow = new HBox(false, 0);
         second.packStart(secondRow, false, false, 0);
 
         // Add an empty label
-        secondRow.packStart(this.createEmptyLabel(), false, false, 0);
+        secondRow.packStart(createEmptyLabel(), false, false, 0);
 
         // Box for check buttons
         final VBox buttons = new VBox(false, 6);
@@ -578,14 +564,14 @@ public final class PreferencesDialog extends Dialog implements Window.DeleteEven
         page.packStart(third, false, false, 0);
 
         // Add the label
-        third.packStart(this.createSectionLabel(_("Default directory")), false, false, 0);
+        third.packStart(createSectionLabel(_("Default directory")), false, false, 0);
 
         // Add the row of option
         final HBox thirdRow = new HBox(false, 0);
         third.packStart(thirdRow, false, false, 0);
 
         // Add an empty label
-        thirdRow.packStart(this.createEmptyLabel(), false, false, 0);
+        thirdRow.packStart(createEmptyLabel(), false, false, 0);
 
         // Default directory button
         mergeDirChooser = new FileChooserButton(_("Choose a directory."),
@@ -611,14 +597,14 @@ public final class PreferencesDialog extends Dialog implements Window.DeleteEven
         page.packStart(first, false, false, 0);
 
         // Add the label
-        first.packStart(this.createSectionLabel(_("Power management")), false, false, 0);
+        first.packStart(createSectionLabel(_("Power management")), false, false, 0);
 
         // Add the row of options
         final HBox firstRow = new HBox(false, 0);
         first.packStart(firstRow, false, false, 0);
 
         // Add an empty label
-        firstRow.packStart(this.createEmptyLabel(), false, false, 0);
+        firstRow.packStart(createEmptyLabel(), false, false, 0);
 
         // Restore hibernation status
         final CheckButton hibernation = new CheckButton(
@@ -639,14 +625,14 @@ public final class PreferencesDialog extends Dialog implements Window.DeleteEven
         page.packStart(second, false, false, 0);
 
         // Add the label
-        second.packStart(this.createSectionLabel(_("Notification")), false, false, 0);
+        second.packStart(createSectionLabel(_("Notification")), false, false, 0);
 
         // Add the row of options
         final HBox secondRow = new HBox(false, 0);
         second.packStart(secondRow, false, false, 0);
 
         // Add an empty label
-        secondRow.packStart(this.createEmptyLabel(), false, false, 0);
+        secondRow.packStart(createEmptyLabel(), false, false, 0);
 
         // Box to pack buttons
         final VBox checks = new VBox(false, 6);
@@ -663,7 +649,7 @@ public final class PreferencesDialog extends Dialog implements Window.DeleteEven
                 config.SHOW_STATUS_ICON = showStatusIcon;
 
                 // Display icon and save preferences
-                app.getMainWindow().getAreaStatusIcon().setVisible(showStatusIcon);
+                ui.getAreaStatusIcon().setVisible(showStatusIcon);
                 config.savePreferences();
             }
         });
@@ -716,5 +702,6 @@ public final class PreferencesDialog extends Dialog implements Window.DeleteEven
 
         // Hide the dialog
         this.hide();
+        this.destroy();
     }
 }
